@@ -1,14 +1,14 @@
 import logging
-from typing import List
 
 from bs4 import BeautifulSoup
 
 from enex2notion.enex_types import EvernoteNote
 from enex2notion.note_parser_blocks import parse_note_blocks
+from enex2notion.note_parser_condense import condense_lines
 from enex2notion.note_parser_webclip import parse_webclip
 from enex2notion.note_parser_webclip_pdf import parse_webclip_to_pdf
-from enex2notion.notion_blocks import NotionBaseBlock, NotionTextBlock, TextProp
 from enex2notion.notion_blocks_container import NotionCalloutBlock
+from enex2notion.notion_blocks_text import TextProp
 from enex2notion.notion_blocks_uploadable import NotionUploadableBlock
 
 logger = logging.getLogger(__name__)
@@ -35,9 +35,9 @@ def parse_note(
         note_blocks = parse_note_blocks(note_dom)
 
     if is_condense_lines_sparse:
-        note_blocks = _condense_lines(note_blocks, is_sparse=True)
+        note_blocks = condense_lines(note_blocks, is_sparse=True)
     elif is_condense_lines:
-        note_blocks = _condense_lines(note_blocks)
+        note_blocks = condense_lines(note_blocks)
 
     if is_add_meta:
         _add_meta(note_blocks, note)
@@ -114,70 +114,3 @@ def _get_note_meta(note: EvernoteNote):
         note_meta.append(f"Tags: {note_tags}")
 
     return "\n".join(note_meta)
-
-
-def _condense_lines(blocks: List[NotionBaseBlock], is_sparse=False):
-    result_blocks = []
-    solid_block = None
-
-    blocks = _join_empty_paragraphs(blocks)
-
-    for b in blocks:
-        b.children = _condense_lines(b.children)
-
-        if _is_empty_paragraph(b) or not isinstance(b, NotionTextBlock):
-            if solid_block:
-                result_blocks.append(solid_block)
-                solid_block = None
-
-            if not _is_empty_paragraph(b) or is_sparse:
-                result_blocks.append(b)
-
-        else:
-            if solid_block:
-                solid_block = NotionTextBlock(
-                    text_prop=_concat_text_props(solid_block.text_prop, b.text_prop)
-                )
-            else:
-                solid_block = b
-
-            if b.children:
-                solid_block.children = b.children
-                result_blocks.append(solid_block)
-                solid_block = None
-
-    if solid_block:
-        result_blocks.append(solid_block)
-
-    return result_blocks
-
-
-def _join_empty_paragraphs(blocks: List[NotionBaseBlock]):
-    result_blocks = []
-    gap_started = False
-
-    for b in blocks:
-        if _is_empty_paragraph(b):
-            gap_started = True
-
-        else:
-            if gap_started:
-                result_blocks.append(NotionTextBlock())
-                gap_started = False
-
-            result_blocks.append(b)
-
-    return result_blocks
-
-
-def _is_empty_paragraph(block: NotionBaseBlock):
-    if isinstance(block, NotionTextBlock):
-        return block == NotionTextBlock()
-    return False
-
-
-def _concat_text_props(text_prop1: TextProp, text_prop2: TextProp) -> TextProp:
-    return TextProp(
-        text=text_prop1.text + "\n" + text_prop2.text,
-        properties=text_prop1.properties + [["\n"]] + text_prop2.properties,
-    )
